import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { SharedGalleryImages } from "../operationsInterfaces";
import { ComputeManagementClient } from "../computeManagementClient";
import { SharedGalleryImage, SharedGalleryImagesListOptionalParams, SharedGalleryImagesGetOptionalParams, SharedGalleryImagesGetResponse } from "../models";
/** Class containing SharedGalleryImages operations. */
export declare class SharedGalleryImagesImpl implements SharedGalleryImages {
    private readonly client;
    /**
     * Initialize a new instance of the class SharedGalleryImages class.
     * @param client Reference to the service client
     */
    constructor(client: ComputeManagementClient);
    /**
     * List shared gallery images by subscription id or tenant id.
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param options The options parameters.
     */
    list(location: string, galleryUniqueName: string, options?: SharedGalleryImagesListOptionalParams): PagedAsyncIterableIterator<SharedGalleryImage>;
    private listPagingPage;
    private listPagingAll;
    /**
     * List shared gallery images by subscription id or tenant id.
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param options The options parameters.
     */
    private _list;
    /**
     * Get a shared gallery image by subscription id or tenant id.
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param galleryImageName The name of the Shared Gallery Image Definition from which the Image
     *                         Versions are to be listed.
     * @param options The options parameters.
     */
    get(location: string, galleryUniqueName: string, galleryImageName: string, options?: SharedGalleryImagesGetOptionalParams): Promise<SharedGalleryImagesGetResponse>;
    /**
     * ListNext
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
}
//# sourceMappingURL=sharedGalleryImages.d.ts.map